"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Template = void 0;
const file_helper_1 = require("../helper/file-helper");
const count_helper_1 = require("../helper/count-helper");
const xml_template_helper_1 = require("../helper/xml-template-helper");
class Template {
    constructor(location) {
        this.location = location;
        const file = file_helper_1.FileHelper.readFile(location);
        this.archive = file_helper_1.FileHelper.extractFileContent(file);
    }
    static import(location, name) {
        let newTemplate;
        if (name) {
            newTemplate = new Template(location);
            newTemplate.name = name;
        }
        else {
            newTemplate = new Template(location);
            newTemplate.slides = [];
            newTemplate.counter = [
                new count_helper_1.CountHelper('slides', newTemplate),
                new count_helper_1.CountHelper('charts', newTemplate),
                new count_helper_1.CountHelper('images', newTemplate),
            ];
        }
        return newTemplate;
    }
    setCreationIds() {
        return __awaiter(this, void 0, void 0, function* () {
            const archive = yield this.archive;
            const xmlTemplateHelper = new xml_template_helper_1.XmlTemplateHelper(archive);
            this.creationIds = yield xmlTemplateHelper.getCreationIds();
            return this.creationIds;
        });
    }
    appendSlide(slide) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.counter[0].get() === undefined) {
                yield this.initializeCounter();
            }
            yield slide.append(this);
        });
    }
    initializeCounter() {
        return __awaiter(this, void 0, void 0, function* () {
            for (const c of this.counter) {
                yield c.set();
            }
        });
    }
    incrementCounter(name) {
        return count_helper_1.CountHelper.increment(name, this.counter);
    }
    count(name) {
        return count_helper_1.CountHelper.count(name, this.counter);
    }
}
exports.Template = Template;
//# sourceMappingURL=template.js.map