"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileHelper = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const jszip_1 = __importDefault(require("jszip"));
class FileHelper {
    static readFile(location) {
        if (!fs_1.default.existsSync(location)) {
            throw new Error('File not found: ' + location);
        }
        return fs_1.default.promises.readFile(location);
    }
    static extractFromArchive(archive, file, type) {
        if (archive === undefined) {
            throw new Error('No files found, expected: ' + file);
        }
        if (archive.files[file] === undefined) {
            console.trace();
            throw new Error('Archived file not found: ' + file);
        }
        return archive.files[file].async(type || 'string');
    }
    static extractFileContent(file) {
        const zip = new jszip_1.default();
        return zip.loadAsync(file);
    }
    static getFileExtension(filename) {
        return path_1.default.extname(filename).replace('.', '');
    }
    /**
     * Copies a file from one archive to another. The new file can have a different name to the origin.
     * @param {JSZip} sourceArchive - Source archive
     * @param {string} sourceFile - file path and name inside source archive
     * @param {JSZip} targetArchive - Target archive
     * @param {string} targetFile - file path and name inside target archive
     * @return {JSZip} targetArchive as an instance of JSZip
     */
    static zipCopy(sourceArchive, sourceFile, targetArchive, targetFile) {
        return __awaiter(this, void 0, void 0, function* () {
            if (sourceArchive.files[sourceFile] === undefined) {
                throw new Error(`Zipped file not found: ${sourceFile}`);
            }
            const content = sourceArchive.files[sourceFile].async('nodebuffer');
            return targetArchive.file(targetFile || sourceFile, content);
        });
    }
    static writeOutputFile(location, content, automizer) {
        return __awaiter(this, void 0, void 0, function* () {
            yield fs_1.default.promises.writeFile(location, content).catch((err) => {
                console.error(err);
                throw new Error(`Could not write output file: ${location}`);
            });
            const duration = (Date.now() - automizer.timer) / 600;
            return {
                status: 'finished',
                duration,
                file: location,
                filename: path_1.default.basename(location),
                templates: automizer.templates.length,
                slides: automizer.rootTemplate.count('slides'),
                charts: automizer.rootTemplate.count('charts'),
                images: automizer.rootTemplate.count('images'),
            };
        });
    }
}
exports.FileHelper = FileHelper;
//# sourceMappingURL=file-helper.js.map