"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cell_id_helper_1 = __importDefault(require("./cell-id-helper"));
const general_helper_1 = require("./general-helper");
const xml_helper_1 = require("./xml-helper");
const xml_elements_1 = __importDefault(require("./xml-elements"));
class ModifyXmlHelper {
    constructor(root) {
        this.root = root;
    }
    modify(tags, root) {
        root = root || this.root;
        for (const tag in tags) {
            const modifier = tags[tag];
            if (general_helper_1.GeneralHelper.propertyExists(modifier, 'collection')) {
                const modifies = general_helper_1.GeneralHelper.arrayify(modifier.collection);
                const collection = root.getElementsByTagName(tag);
                Object.values(modifies).forEach((modifyXml) => modifyXml(collection));
                return;
            }
            const index = modifier.index || 0;
            const isRequired = (modifier.isRequired !== undefined)
                ? modifier.isRequired : true;
            const asserted = this.assertNode(root.getElementsByTagName(tag), index, tag, root, isRequired);
            if (asserted === false) {
                if (isRequired === true) {
                    // XmlHelper.dump(root)
                    // vd(tags)
                    (0, general_helper_1.vd)('Could not assert required tag: ' + tag + '@index:' + index);
                }
                return;
            }
            const element = root.getElementsByTagName(tag)[index];
            if (general_helper_1.GeneralHelper.propertyExists(modifier, 'modify')) {
                const modifies = general_helper_1.GeneralHelper.arrayify(modifier.modify);
                Object.values(modifies).forEach((modifyXml) => modifyXml(element));
            }
            if (general_helper_1.GeneralHelper.propertyExists(modifier, 'children')) {
                this.modify(modifier.children, element);
            }
        }
    }
    assertNode(collection, index, tag, parent, required) {
        if (!collection[index]) {
            if (collection[collection.length - 1] === undefined) {
                return this.createNode(parent, tag, index, required);
            }
            else {
                const tplNode = collection[collection.length - 1];
                const newChild = tplNode.cloneNode(true);
                xml_helper_1.XmlHelper.insertAfter(newChild, tplNode);
            }
        }
        return true;
    }
    createNode(parent, tag, index, required) {
        switch (tag) {
            case 'a:t':
                new xml_elements_1.default(parent).text();
                return true;
            case 'c:dPt':
                new xml_elements_1.default(parent).dataPoint();
                return true;
            case 'c:spPr':
                new xml_elements_1.default(parent).shapeProperties();
                return true;
        }
        //
        // if(required === true) {
        //   throw new Error(
        //     `Could not create new node at index ${index}; Tag "${tag}"`,
        //   );
        // }
        return false;
    }
}
exports.default = ModifyXmlHelper;
ModifyXmlHelper.getText = (element) => {
    return element.firstChild.textContent;
};
ModifyXmlHelper.value = (value, index) => (element) => {
    element.getElementsByTagName('c:v')[0].firstChild.textContent = String(value);
    if (index !== undefined) {
        element.setAttribute('idx', String(index));
    }
};
ModifyXmlHelper.attribute = (attribute, value) => (element) => {
    element.setAttribute(attribute, String(value));
};
ModifyXmlHelper.booleanAttribute = (attribute, state) => (element) => {
    element.setAttribute(attribute, (state === true) ? '1' : '0');
};
ModifyXmlHelper.range = (series, length) => (element) => {
    const range = element.firstChild.textContent;
    element.firstChild.textContent = cell_id_helper_1.default.setRange(range, series, length);
};
//# sourceMappingURL=modify-xml-helper.js.map