import JSZip from 'jszip';
import { DefaultAttribute, OverrideAttribute, RelationshipAttribute, HelperElement } from '../types/xml-types';
import { GetRelationshipsCallback, Target } from '../types/types';
export declare class XmlHelper {
    static getXmlFromArchive(archive: JSZip, file: string): Promise<XMLDocument>;
    static writeXmlToArchive(archive: JSZip, file: string, xml: XMLDocument): Promise<JSZip>;
    static appendIf(element: HelperElement): Promise<HelperElement | boolean>;
    static append(element: HelperElement): Promise<HelperElement>;
    static getNextRelId(rootArchive: JSZip, file: string): Promise<string>;
    static getMaxId(rels: NodeListOf<ChildNode> | HTMLCollectionOf<Element>, attribute: string, increment?: boolean, minId?: number): number;
    static getTargetsFromRelationships(archive: JSZip, path: string, prefix: string, suffix?: string | RegExp): Promise<Target[]>;
    static getTargetsByRelationshipType(archive: JSZip, path: string, type: string): Promise<Target[]>;
    static getRelationships(archive: JSZip, path: string, cb: GetRelationshipsCallback): Promise<Target[]>;
    static findByAttribute(xml: XMLDocument | Document, tagName: string, attributeName: string, attributeValue: string): boolean;
    static replaceAttribute(archive: JSZip, path: string, tagName: string, attributeName: string, attributeValue: string, replaceValue: string): Promise<JSZip>;
    static getTargetByRelId(archive: JSZip, slideNumber: number, element: XMLDocument, type: string): Promise<Target>;
    static findByElementCreationId(archive: JSZip, path: string, creationId: string): Promise<XMLDocument>;
    static findByElementName(archive: JSZip, path: string, name: string): Promise<XMLDocument>;
    static findByName(doc: Document, name: string): XMLDocument;
    static findByCreationId(doc: Document, creationId: string): XMLDocument;
    static findByAttributeValue(nodes: NodeListOf<ChildNode> | HTMLCollectionOf<Element>, attributeName: string, attributeValue: string): Element;
    static createContentTypeChild(archive: JSZip, attributes: OverrideAttribute | DefaultAttribute): HelperElement;
    static createRelationshipChild(archive: JSZip, targetRelFile: string, attributes: RelationshipAttribute): HelperElement;
    static appendSharedString(sharedStrings: Document, stringValue: string): number;
    static insertAfter(newNode: Node, referenceNode: Element): void;
    static sliceCollection(collection: HTMLCollectionOf<Element>, length: number): void;
    static dump(element: XMLDocument | Element): void;
}
