"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModifyTable = void 0;
const xml_helper_1 = require("../helper/xml-helper");
const modify_xml_helper_1 = __importDefault(require("../helper/modify-xml-helper"));
const modify_text_helper_1 = __importDefault(require("../helper/modify-text-helper"));
class ModifyTable {
    constructor(table, data) {
        this.row = (index, children) => {
            return {
                'a:tr': {
                    index: index,
                    children: children,
                },
            };
        };
        this.column = (index, children) => {
            return {
                'a:tc': {
                    index: index,
                    children: children,
                },
            };
        };
        this.cell = (value, style) => {
            return {
                'a:t': {
                    modify: modify_text_helper_1.default.content(value),
                },
                'a:rPr': {
                    modify: modify_text_helper_1.default.style(style),
                },
            };
        };
        this.data = data;
        this.table = new modify_xml_helper_1.default(table);
        this.xml = table;
    }
    modify() {
        this.setRows();
        this.setGridCols();
        this.sliceRows();
        this.sliceCols();
        return this;
    }
    setRows() {
        this.data.body.forEach((row, r) => {
            row.values.forEach((cell, c) => {
                const rowStyles = (row.styles && row.styles[c]) ? row.styles[c] : {};
                this.table.modify(this.row(r, this.column(c, this.cell(cell, rowStyles))));
                this.table.modify({
                    'a16:rowId': {
                        index: r,
                        modify: modify_xml_helper_1.default.attribute('val', r),
                    },
                });
            });
        });
    }
    setGridCols() {
        this.data.body[0].values.forEach((cell, c) => {
            this.table.modify({
                'a:gridCol': {
                    index: c,
                },
                'a16:colId': {
                    index: c,
                    modify: modify_xml_helper_1.default.attribute('val', c),
                },
            });
        });
    }
    sliceRows() {
        this.table.modify({
            'a:tbl': this.slice('a:tr', this.data.body.length),
        });
    }
    sliceCols() {
        this.table.modify({
            'a:tblGrid': this.slice('a:gridCol', this.data.body[0].values.length),
        });
    }
    slice(tag, length) {
        return {
            children: {
                [tag]: {
                    collection: (collection) => {
                        xml_helper_1.XmlHelper.sliceCollection(collection, length);
                    },
                },
            },
        };
    }
    adjustHeight() {
        const tableHeight = this.getTableSize('cy');
        const rowHeight = tableHeight / this.data.body.length;
        this.data.body.forEach((row, r) => {
            this.table.modify({
                'a:tr': {
                    index: r,
                    modify: modify_xml_helper_1.default.attribute('h', Math.round(rowHeight)),
                },
            });
        });
        return this;
    }
    adjustWidth() {
        const tableWidth = this.getTableSize('cx');
        const rowWidth = tableWidth / this.data.body[0].values.length;
        this.data.body[0].values.forEach((cell, c) => {
            this.table.modify({
                'a:gridCol': {
                    index: c,
                    modify: modify_xml_helper_1.default.attribute('w', Math.round(rowWidth)),
                },
            });
        });
        return this;
    }
    getTableSize(orientation) {
        return Number(this.xml
            .getElementsByTagName('p:xfrm')[0]
            .getElementsByTagName('a:ext')[0]
            .getAttribute(orientation));
    }
}
exports.ModifyTable = ModifyTable;
//# sourceMappingURL=modify-table.js.map