"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Chart = void 0;
const file_helper_1 = require("../helper/file-helper");
const xml_helper_1 = require("../helper/xml-helper");
const shape_1 = require("../classes/shape");
class Chart extends shape_1.Shape {
    constructor(shape) {
        super(shape);
        this.relRootTag = 'c:chart';
        this.relAttribute = 'r:id';
        this.relParent = (element) => element.parentNode.parentNode.parentNode;
        this.wbEmbeddingsPath = `../embeddings/`;
        this.wbExtension = '.xlsx';
        this.relTypeChartColorStyle =
            'http://schemas.microsoft.com/office/2011/relationships/chartColorStyle';
        this.relTypeChartStyle =
            'http://schemas.microsoft.com/office/2011/relationships/chartStyle';
        this.styleRelationFiles = {};
    }
    modify(targetTemplate, targetSlideNumber) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.prepare(targetTemplate, targetSlideNumber);
            yield this.clone();
            yield this.replaceIntoSlideTree();
            return this;
        });
    }
    append(targetTemplate, targetSlideNumber) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.prepare(targetTemplate, targetSlideNumber);
            yield this.clone();
            yield this.appendToSlideTree();
            return this;
        });
    }
    modifyOnAddedSlide(targetTemplate, targetSlideNumber) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.prepare(targetTemplate, targetSlideNumber);
            yield this.updateElementRelId();
            return this;
        });
    }
    prepare(targetTemplate, targetSlideNumber) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.setTarget(targetTemplate, targetSlideNumber);
            this.targetNumber = this.targetTemplate.incrementCounter('charts');
            this.wbRelsPath = `ppt/charts/_rels/chart${this.sourceNumber}.xml.rels`;
            yield this.copyFiles();
            yield this.copyChartStyleFiles();
            yield this.appendTypes();
            yield this.appendToSlideRels();
        });
    }
    clone() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.setTargetElement();
            yield this.modifyChartData();
            yield this.updateTargetElementRelId();
        });
    }
    modifyChartData() {
        return __awaiter(this, void 0, void 0, function* () {
            const chartXml = yield xml_helper_1.XmlHelper.getXmlFromArchive(this.targetArchive, `ppt/charts/chart${this.targetNumber}.xml`);
            const workbook = yield this.readWorkbook();
            this.applyCallbacks(this.callbacks, this.targetElement, chartXml, workbook);
            yield xml_helper_1.XmlHelper.writeXmlToArchive(this.targetArchive, `ppt/charts/chart${this.targetNumber}.xml`, chartXml);
            yield this.writeWorkbook(workbook);
        });
    }
    readWorkbook() {
        return __awaiter(this, void 0, void 0, function* () {
            const worksheet = yield file_helper_1.FileHelper.extractFromArchive(this.targetArchive, `ppt/embeddings/${this.worksheetFilePrefix}${this.targetWorksheet}${this.wbExtension}`, 'nodebuffer');
            const archive = yield file_helper_1.FileHelper.extractFileContent(worksheet);
            const sheet = yield xml_helper_1.XmlHelper.getXmlFromArchive(archive, 'xl/worksheets/sheet1.xml');
            const table = yield xml_helper_1.XmlHelper.getXmlFromArchive(archive, 'xl/tables/table1.xml');
            const sharedStrings = yield xml_helper_1.XmlHelper.getXmlFromArchive(archive, 'xl/sharedStrings.xml');
            return {
                archive,
                sheet,
                sharedStrings,
                table,
            };
        });
    }
    writeWorkbook(workbook) {
        return __awaiter(this, void 0, void 0, function* () {
            yield xml_helper_1.XmlHelper.writeXmlToArchive(workbook.archive, 'xl/worksheets/sheet1.xml', workbook.sheet);
            yield xml_helper_1.XmlHelper.writeXmlToArchive(workbook.archive, 'xl/tables/table1.xml', workbook.table);
            yield xml_helper_1.XmlHelper.writeXmlToArchive(workbook.archive, 'xl/sharedStrings.xml', workbook.sharedStrings);
            const worksheet = yield workbook.archive.generateAsync({
                type: 'nodebuffer',
            });
            this.targetArchive.file(`ppt/embeddings/${this.worksheetFilePrefix}${this.targetWorksheet}${this.wbExtension}`, worksheet);
        });
    }
    copyFiles() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.copyChartFiles();
            this.worksheetFilePrefix = yield this.getWorksheetFilePrefix(this.wbRelsPath);
            const worksheets = yield xml_helper_1.XmlHelper.getTargetsFromRelationships(this.sourceArchive, this.wbRelsPath, `${this.wbEmbeddingsPath}${this.worksheetFilePrefix}`, this.wbExtension);
            const worksheet = worksheets[0];
            this.sourceWorksheet = worksheet.number === 0 ? '' : worksheet.number;
            this.targetWorksheet = '-created-' + this.targetNumber;
            yield this.copyWorksheetFile();
            yield this.editTargetWorksheetRel();
        });
    }
    getWorksheetFilePrefix(targetRelFile) {
        return __awaiter(this, void 0, void 0, function* () {
            const relationTargets = yield xml_helper_1.XmlHelper.getTargetsFromRelationships(this.sourceArchive, targetRelFile, this.wbEmbeddingsPath, this.wbExtension);
            const wbPath = relationTargets[0].file
                .replace(this.wbEmbeddingsPath, '')
                .replace(this.wbExtension, '');
            const wbTitle = wbPath.match(/^(.+?)(\d+)*$/);
            return wbTitle[0];
        });
    }
    appendTypes() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.appendChartExtensionToContentType();
            yield this.appendChartToContentType();
            yield this.appendColorToContentType();
            yield this.appendStyleToContentType();
        });
    }
    copyChartFiles() {
        return __awaiter(this, void 0, void 0, function* () {
            yield file_helper_1.FileHelper.zipCopy(this.sourceArchive, `ppt/charts/chart${this.sourceNumber}.xml`, this.targetArchive, `ppt/charts/chart${this.targetNumber}.xml`);
            yield file_helper_1.FileHelper.zipCopy(this.sourceArchive, `ppt/charts/_rels/chart${this.sourceNumber}.xml.rels`, this.targetArchive, `ppt/charts/_rels/chart${this.targetNumber}.xml.rels`);
        });
    }
    copyChartStyleFiles() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.getChartStyles();
            if (this.styleRelationFiles.relTypeChartStyle) {
                yield file_helper_1.FileHelper.zipCopy(this.sourceArchive, `ppt/charts/${this.styleRelationFiles.relTypeChartStyle}`, this.targetArchive, `ppt/charts/style${this.targetNumber}.xml`);
            }
            if (this.styleRelationFiles.relTypeChartColorStyle) {
                yield file_helper_1.FileHelper.zipCopy(this.sourceArchive, `ppt/charts/${this.styleRelationFiles.relTypeChartColorStyle}`, this.targetArchive, `ppt/charts/colors${this.targetNumber}.xml`);
            }
        });
    }
    getChartStyles() {
        return __awaiter(this, void 0, void 0, function* () {
            const styleTypes = ['relTypeChartStyle', 'relTypeChartColorStyle'];
            for (const i in styleTypes) {
                const styleType = styleTypes[i];
                const styleRelation = yield xml_helper_1.XmlHelper.getTargetsByRelationshipType(this.sourceArchive, this.wbRelsPath, this[styleType]);
                if (styleRelation.length) {
                    this.styleRelationFiles[styleType] = styleRelation[0].file;
                }
            }
        });
    }
    appendToSlideRels() {
        return __awaiter(this, void 0, void 0, function* () {
            this.createdRid = yield xml_helper_1.XmlHelper.getNextRelId(this.targetArchive, this.targetSlideRelFile);
            const attributes = {
                Id: this.createdRid,
                Type: 'http://schemas.openxmlformats.org/officeDocument/2006/relationships/chart',
                Target: `../charts/chart${this.targetNumber}.xml`,
            };
            return xml_helper_1.XmlHelper.append(xml_helper_1.XmlHelper.createRelationshipChild(this.targetArchive, this.targetSlideRelFile, attributes));
        });
    }
    editTargetWorksheetRel() {
        return __awaiter(this, void 0, void 0, function* () {
            const targetRelFile = `ppt/charts/_rels/chart${this.targetNumber}.xml.rels`;
            const relXml = yield xml_helper_1.XmlHelper.getXmlFromArchive(this.targetArchive, targetRelFile);
            const relations = relXml.getElementsByTagName('Relationship');
            Object.keys(relations)
                .map((key) => relations[key])
                .filter((element) => element.getAttribute)
                .forEach((element) => {
                const type = element.getAttribute('Type');
                switch (type) {
                    case 'http://schemas.openxmlformats.org/officeDocument/2006/relationships/package':
                        element.setAttribute('Target', `${this.wbEmbeddingsPath}${this.worksheetFilePrefix}${this.targetWorksheet}${this.wbExtension}`);
                        break;
                    case this.relTypeChartColorStyle:
                        element.setAttribute('Target', `colors${this.targetNumber}.xml`);
                        break;
                    case this.relTypeChartStyle:
                        element.setAttribute('Target', `style${this.targetNumber}.xml`);
                        break;
                }
            });
            yield xml_helper_1.XmlHelper.writeXmlToArchive(this.targetArchive, targetRelFile, relXml);
        });
    }
    copyWorksheetFile() {
        return __awaiter(this, void 0, void 0, function* () {
            yield file_helper_1.FileHelper.zipCopy(this.sourceArchive, `ppt/embeddings/${this.worksheetFilePrefix}${this.sourceWorksheet}${this.wbExtension}`, this.targetArchive, `ppt/embeddings/${this.worksheetFilePrefix}${this.targetWorksheet}${this.wbExtension}`);
        });
    }
    appendChartExtensionToContentType() {
        return xml_helper_1.XmlHelper.appendIf(Object.assign(Object.assign({}, xml_helper_1.XmlHelper.createContentTypeChild(this.targetArchive, {
            Extension: `xlsx`,
            ContentType: `application/vnd.openxmlformats-officedocument.spreadsheetml.sheet`,
        })), { tag: 'Default', clause: (xml) => !xml_helper_1.XmlHelper.findByAttribute(xml, 'Default', 'Extension', 'xlsx') }));
    }
    appendChartToContentType() {
        return xml_helper_1.XmlHelper.append(xml_helper_1.XmlHelper.createContentTypeChild(this.targetArchive, {
            PartName: `/ppt/charts/chart${this.targetNumber}.xml`,
            ContentType: `application/vnd.openxmlformats-officedocument.drawingml.chart+xml`,
        }));
    }
    appendColorToContentType() {
        return xml_helper_1.XmlHelper.append(xml_helper_1.XmlHelper.createContentTypeChild(this.targetArchive, {
            PartName: `/ppt/charts/colors${this.targetNumber}.xml`,
            ContentType: `application/vnd.ms-office.chartcolorstyle+xml`,
        }));
    }
    appendStyleToContentType() {
        return xml_helper_1.XmlHelper.append(xml_helper_1.XmlHelper.createContentTypeChild(this.targetArchive, {
            PartName: `/ppt/charts/style${this.targetNumber}.xml`,
            ContentType: `application/vnd.ms-office.chartstyle+xml`,
        }));
    }
    static getAllOnSlide(archive, relsPath) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield xml_helper_1.XmlHelper.getTargetsFromRelationships(archive, relsPath, '../charts/chart');
        });
    }
}
exports.Chart = Chart;
//# sourceMappingURL=chart.js.map